@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -18,7 +18,7 @@ def detect(get_page):
     for vector in WAF_ATTACK_VECTORS:
         page, headers, _ = get_page(get=vector)
         retval = "This request is blocked by the SonicWALL" in (page or "")
-        retval |= all(_ in page or "" for _ in ("#shd", "#nsa_banner"))
+        retval |= all(_ in (page or "") for _ in ("#shd", "#nsa_banner"))
         retval |= re.search(r"Web Site Blocked.+\bnsa_banner", page or "", re.I) is not None
         retval |= re.search(r"SonicWALL", headers.get(HTTP_HEADER.SERVER, ""), re.I) is not None
         if retval:
